TestEnv

Struct TestEnv 

pub struct TestEnv {
    pub ext_caches: ExtensionCaches,
    pub widget_caches: WidgetCaches,
    pub images: ImageRegistry,
    pub theme: Theme,
    pub dispatcher: ExtensionDispatcher,
    pub default_text_size: Option<f32>,
    pub default_font: Option<Font>,
}
Owns all the dependencies needed to construct a WidgetEnv for testing extension render() methods.

All fields are public so tests can customize before calling env.

Example

let test = TestEnv::default();
let env = test.env();
let element = my_extension.render(&node, &env);

With customization:

let test = TestEnv {
    theme: Theme::Light,
    ..TestEnv::default()
};
let env = test.env();

Fields

ext_caches: ExtensionCacheswidget_caches: WidgetCachesimages: ImageRegistrytheme: Themedispatcher: ExtensionDispatcherdefault_text_size: Option<f32>default_font: Option<Font>

Implementations

Source

impl TestEnv

pub fn render_ctx(&self) -> RenderCtx<'_>

Build a RenderCtx from the owned test state.

pub fn env<'a>(&'a self, ctx: &RenderCtx<'a>) -> WidgetEnv<'a>

Borrow a WidgetEnv using an externally-held RenderCtx.

Usage:

let test = TestEnv::default();
let ctx = test.render_ctx();
let env = test.env(&ctx);
let element = my_extension.render(&node, &env);